Trait system_interface::io::IsTerminal [−][src]
pub trait IsTerminal {
fn is_terminal(&self) -> bool;
}Expand description
Extension for I/O handles which may or may not be terminals.
Required methods
fn is_terminal(&self) -> bool[src]
Test whether this output stream is attached to a terminal.
This operation is also known as isatty.
Implementations on Foreign Types
impl<'a> IsTerminal for StdinLock<'a>[src]
impl<'a> IsTerminal for StdinLock<'a>[src]Implement IsTerminal for StdinLock.
fn is_terminal(&self) -> bool[src]
impl<'a> IsTerminal for StdoutLock<'a>[src]
impl<'a> IsTerminal for StdoutLock<'a>[src]Implement IsTerminal for StdoutLock.
fn is_terminal(&self) -> bool[src]
impl<'a> IsTerminal for StderrLock<'a>[src]
impl<'a> IsTerminal for StderrLock<'a>[src]Implement IsTerminal for StderrLock.
fn is_terminal(&self) -> bool[src]
impl<'a> IsTerminal for File[src]
impl<'a> IsTerminal for File[src]Implement IsTerminal for std::fs::File.
fn is_terminal(&self) -> bool[src]
impl<'a> IsTerminal for TcpStream[src]
impl<'a> IsTerminal for TcpStream[src]Implement IsTerminal for std::net::TcpStream.