[][src]Trait system_interface::io::IsTerminal

pub trait IsTerminal {
    fn is_terminal(&self) -> Result<bool>;
}

Extension for I/O handles which may or may not be terminals.

Required methods

fn is_terminal(&self) -> Result<bool>

Test whether this output stream is attached to a terminal.

This operation is also known as isatty.

Loading content...

Implementors

impl<T> IsTerminal for T where
    T: AsRawFd
[src]

Implement IsTerminal for types that implement AsRawFd.

Loading content...